@@ -1,5 +1,4 @@
 use assert_matches::assert_matches;
-use prae::Guard;
 
 prae::define! {
     pub Username: String
@@ -7,23 +6,21 @@ prae::define! {
 }
 
 #[test]
-#[ignore] // FIXME
 fn construction_error_formats_correctly() {
     let err = Username::new("").unwrap_err();
     assert_eq!(
         err.to_string(),
-        "failed to create Username from value \"\": provided value is invalid"
+        "failed to construct type Username from value \"\": value is invalid"
     );
 }
 
 #[test]
-#[ignore] // FIXME
 fn mutation_error_formats_correctly() {
     let mut un = Username::new("user").unwrap();
-    let err = un.try_mutate(|u| *u = "".to_owned()).unwrap_err();
+    let err = un.mutate(|u| *u = "".to_owned()).unwrap_err();
     assert_eq!(
         err.to_string(),
-        "failed to mutate Username from value \"user\" to \"\": provided value is invalid"
+        "failed to mutate type Username from value \"user\" to value \"\": value is invalid"
     );
 }
 
@@ -42,21 +39,7 @@ fn construction_succeeds_for_valid_data() {
 fn mutation_fails_for_invalid_data() {
     let mut un = Username::new("user").unwrap();
     assert_matches!(
-        un.try_mutate(|u| *u = "".to_owned()),
+        un.mutate(|u| *u = "".to_owned()),
         Err(prae::MutationError { .. })
     )
 }
-
-#[test]
-#[should_panic]
-fn mutation_panics_for_invalid_data() {
-    let mut un = Username::new("user").unwrap();
-    un.mutate(|u| *u = "".to_owned());
-}
-
-#[test]
-fn mutation_succeeds_for_valid_data() {
-    let mut un = Username::new("user").unwrap();
-    assert!(un.try_mutate(|u| *u = " new user ".to_owned()).is_ok());
-    assert_eq!(un.get(), " new user ");
-}
