@@ -1,9 +1,7 @@
-use prae::Guard;
-
 prae::define! {
     Text: String
     adjust |t| *t = t.trim().to_owned()
-    validate |t| -> Result<(), &'static str> {
+    validate(&'static str) |t| {
         if t.is_empty() {
             Err("provided text is empty")
         } else {
@@ -12,18 +10,19 @@ prae::define! {
     }
 }
 
-prae::extend! {
-    CapText: Text
+prae::define! {
+    CapText: String
+    extend TextBound
     adjust |t| {
        let mut cs = t.chars();
-        *t = cs.next().unwrap().to_uppercase().collect::<String>() + cs.as_str();
+       *t = cs.next().unwrap().to_uppercase().collect::<String>() + cs.as_str();
     }
 }
 
-prae::extend! {
-    Sentence: CapText
-    validate |s| -> Result<(), String> {
-        eprintln!("{}", &s);
+prae::define! {
+    Sentence: String
+    extend CapTextBound
+    validate(String) |s| {
         if s.ends_with(&['.', '!', '?'][..]) {
             Ok(())
         } else {
@@ -38,7 +37,7 @@ fn extended_works() {
     assert_eq!(t.get(), "A couple of words");
 
     let e = CapText::new(" ").unwrap_err();
-    assert_eq!(e.into_inner(), "provided text is empty");
+    assert_eq!(e.inner, "provided text is empty");
 }
 
 #[test]
@@ -47,11 +46,8 @@ fn double_extended_works() {
     assert_eq!(t.get(), "A sentence.");
 
     let e = Sentence::new(" ").unwrap_err();
-    assert_eq!(e.into_inner(), "provided text is empty");
+    assert_eq!(e.inner, "provided text is empty");
 
     let e = Sentence::new(" a sentence ").unwrap_err();
-    assert_eq!(
-        e.into_inner(),
-        "provided sentence has no ending punctuation mark"
-    );
+    assert_eq!(e.inner, "provided sentence has no ending punctuation mark");
 }
